'use strict';

var React = require('react');

const ThemeProvider = require('../client').ThemeProvider;
// Wraps an <html> element on the server to apply themes before reaching the client
const ServerThemeProvider = ({ children, ...props }) => {
    if (!children || children.type !== 'html') {
        throw new Error('<ServerThemeProvider> must contain the <html> element.');
    }
    const child = children;
    const original = child.props;
    const resolved = { ...original, suppressHydrationWarning: true };
    let newKids;
    if (!original.children) {
        newKids = [];
    }
    else if (!Array.isArray(original.children)) {
        newKids = [original.children];
    }
    else {
        newKids = [...original.children];
    }
    let bodyIndex = newKids.findIndex(x => x && typeof x === 'object' && x.type === 'body');
    let body;
    if (bodyIndex !== -1) {
        body = newKids.splice(bodyIndex, 1)[0];
    }
    else {
        bodyIndex = newKids.length;
        body = React.createElement("body", null);
    }
    let bodyChildren;
    if (!body.props?.children) {
        bodyChildren = [];
    }
    else if (!Array.isArray(body.props.children)) {
        bodyChildren = [body.props.children];
    }
    else {
        bodyChildren = [...body.props.children];
    }
    resolved.children = [
        ...newKids.slice(0, bodyIndex),
        React.cloneElement(body, {
            // children: bodyChildren,
            children: React.createElement(ThemeProvider, { ...props }, bodyChildren)
        }),
        ...newKids.slice(bodyIndex),
    ];
    return React.cloneElement(child, resolved);
};

exports.ServerThemeProvider = ServerThemeProvider;
